@@ -117,17 +117,18 @@ class EasylearnMainGUI(QMainWindow, Ui_MainWindow):
         
         try:
             ss=time.time()
-            r = requests.get('https://github.com/easylearn-fmri/easylearn_dev/blob/dev/eslearn_news.txt', timeout=10)
+            r = requests.get('https://github.com/easylearn-fmri/easylearn_dev/blob/dev/eslearn_news.txt', timeout=5)
             text = r.text
+            return
             ee = time.time()
             print(ee-ss)
         
         except Exception as e:
-            print("Time out (10 sec) when detecting new version!\nPlease check your network connection")
+            print(f"{e}\nwhen detecting new version!\nPlease check your network connection")
             text = ""
             
         except ConnectionError: 
-            print("Time out (10 sec) when detecting new version!\nPlease check your network connection")
+            print(f"Time out (10 sec) when detecting new version!\nPlease check your network connection")
             text = ""
         
         # Version
